!--------------------- BEGIN small_jacobian.f90 BEGIN ---------------------
! @file small_jacobian.f90                                                 
! @author jlinford                                                         
! @date 2012-06-22 15:43:41.259540                                         
! @brief The Jacobian of the chemical model                                
!                                                                          
! The Jacobian of the chemical model                                       
!                                                                          
! This file was generated by Kppa: http://www.paratools.com/Kppa           
!--------------------------------------------------------------------------


MODULE small_jacobian

    USE small_parameters

    IMPLICIT NONE




    CONTAINS

!---------------------------------- Jac -----------------------------------
! The Jacobian of variable species                                         
!                                                                          
! @param[in]     var  Variable species concentrations                      
! @param[in]     fix  Fixed species concentrations                         
! @param[in]     rct  Reaction rates                                       
! @param[out]    sjac The row-compressed sparse Jacobian                   
!--------------------------------------------------------------------------
    SUBROUTINE Jac(var, fix, rct, sjac)
        IMPLICIT NONE

        REAL(4), INTENT(IN) :: var(5)
        REAL(4), INTENT(IN) :: fix(2)
        REAL(4), INTENT(IN) :: rct(10)
        REAL(4), INTENT(OUT) :: sjac(19)

        REAL(4) :: t0
        REAL(4) :: t1
        REAL(4) :: t2
        REAL(4) :: t3
        REAL(4) :: t4
        REAL(4) :: t5
        REAL(4) :: t6
        REAL(4) :: t7
        REAL(4) :: t8
        REAL(4) :: t9
        REAL(4) :: t10
        REAL(4) :: t11
        REAL(4) :: t12

        t0 = 7.11e-11*fix(1)
        t1 = 1.2e-10*var(3)
        t2 = 8.018e-17*fix(2)
        t3 = 1.576e-15*var(3)
        t4 = 1.069e-11*var(5)
        t5 = rct(3)
        t6 = 1.576e-15*var(2)
        t7 = rct(5)
        t8 = 1.2e-10*var(1)
        t9 = 6.062e-15*var(4)
        t10 = 6.062e-15*var(3)
        t11 = 1.069e-11*var(2)
        t12 = rct(10)

        sjac(1) = -t0 - t1
        sjac(2) = t7 - t8
        sjac(3) = t0
        sjac(4) = -t2 - t3 - t4
        sjac(5) = t5 - t6
        sjac(6) = -t11 + t12
        sjac(7) = -t1
        sjac(8) = t2 - t3
        sjac(9) = -t5 - t6 - t7 - t8 - t9
        sjac(10) = -t10
        sjac(11) = 0
        sjac(12) = t4
        sjac(13) = -t9
        sjac(14) = -t10
        sjac(15) = t11 + t12
        sjac(16) = -t4
        sjac(17) = t9
        sjac(18) = t10
        sjac(19) = -t11 - t12
    END SUBROUTINE Jac



END MODULE small_jacobian
!----------------------- END small_jacobian.f90 END -----------------------
